﻿using Stimulsoft.Report;
using Stimulsoft.Report.MobileDesign;
using System;
using System.ComponentModel;
using Wisej.Web;

namespace ReportExampleDesigner
{
	[ToolboxItem(true)]
    public class WebReportDesigner : Wisej.Web.Ext.AspNetControl.AspNetWrapper<Stimulsoft.Report.MobileDesign.StiMobileDesigner>
    {
        #region Properties

        /// <summary>
        /// Returns or sets the filename or full path to the report on the server.
        /// </summary>
        public string Filename
        {
            get
            {
                return this._filename;
            }

            set
            {
                value = value ?? "";
                if (this._filename != value)
                {
                    this._filename = value;
                    Update();
                }
            }
        }
        private string _filename;

        /// <summary>
        /// Returns the Stimulsoft designer instance.
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public StiMobileDesigner Designer
        {
            get { return this.WrappedControl; }
        }

        #endregion

        #region Implementations

        protected override void OnInit(EventArgs e)
		{
			// attach the handled events to fire the event on the wrapper.
			var designer = this.Designer;
			if (this.GetReport != null)
				designer.GetReport += Designer_GetReport;
			if (this.CreateReport != null)
				designer.CreateReport += Designer_CreateReport;
			if (this.PreviewReport != null)
				designer.PreviewReport += Designer_PreviewReport;
			if (this.SaveReport != null)
				designer.SaveReport += Designer_SaveReport;
			if (this.SaveAsReport != null)
				designer.SaveAsReport += Designer_SaveAsReport;

			base.OnInit(e);
		}

		protected override void OnLoad(EventArgs e)
		{
			if (!this.IsPostBack && this.Filename != "")
			{
				LoadReportFile(this.Filename);
			}
			base.OnLoad(e);
		}

        #endregion

        #region Delegates 

        private void Designer_GetReport(object sender, StiMobileDesigner.StiGetReportEventArgs e)
        {
            OnGetReport(e);
        }

        private void Designer_CreateReport(object sender, StiMobileDesigner.StiCreateReportEventArgs e)
        {
            OnCreateReport(e);
        }

        private void Designer_PreviewReport(object sender, StiMobileDesigner.StiPreviewReportEventArgs e)
        {
            OnPreviewReport(e);
        }

        private void Designer_SaveReport(object sender, StiMobileDesigner.StiSaveReportEventArgs e)
        {
            OnSaveReport(e);
        }

        private void Designer_SaveAsReport(object sender, StiMobileDesigner.StiSaveAsReportEventArgs e)
        {
            OnSaveAsReport(e);
        }

        #endregion

        #region Events

        /// <summary>
        /// LoadReport event.
        /// </summary>
        public event StiMobileDesigner.StiGetReportEventHandler GetReport;

        /// <summary>
        /// CreateReport event.
        /// </summary>
        public event StiMobileDesigner.StiCreateReportEventHandler CreateReport;

        /// <summary>
        /// PreviewReport event.
        /// </summary>
        public event StiMobileDesigner.StiPreviewReportEventHandler PreviewReport;

        /// <summary>
        /// SaveReport event.
        /// </summary>
        public event StiMobileDesigner.StiSaveReportEventHandler SaveReport;

        /// <summary>
        /// SaveAsReport event.
        /// </summary>
        public event StiMobileDesigner.StiSaveAsReportEventHandler SaveAsReport;

        /// <summary>
        /// Fires the GetReport event.
        /// </summary>
        /// <param name="e"></param>
        protected void OnGetReport(StiMobileDesigner.StiGetReportEventArgs e)
        {
            this.GetReport?.Invoke(this, e);
        }

        /// <summary>
        /// Fires the CreateReport event.
        /// </summary>
        /// <param name="e"></param>
        protected void OnCreateReport(StiMobileDesigner.StiCreateReportEventArgs e)
        {
            this.CreateReport?.Invoke(this, e);
        }

        /// <summary>
        /// Fires the PreviewReport event.
        /// </summary>
        /// <param name="e"></param>
        protected void OnPreviewReport(StiMobileDesigner.StiPreviewReportEventArgs e)
        {
            this.PreviewReport?.Invoke(this, e);
        }

        /// <summary>
        /// Fires the SaveReport event.
        /// </summary>
        /// <param name="e"></param>
        protected void OnSaveReport(StiMobileDesigner.StiSaveReportEventArgs e)
        {
            this.SaveReport?.Invoke(this, e);
        }

        /// <summary>
        /// Fires the SaveAsReport event.
        /// </summary>
        /// <param name="e"></param>
        protected void OnSaveAsReport(StiMobileDesigner.StiSaveAsReportEventArgs e)
        {
            this.SaveAsReport?.Invoke(this, e);
        }

        #endregion

        #region Methods

        private void LoadReportFile(string fileName)
		{
			var filePath = Application.MapPath(fileName);
			StiReport report = new StiReport();
			report.Load(filePath);
			this.Designer.Report = report;
		}

        #endregion
    }
}